@@ -13,7 +13,8 @@ from .components.config import Config
 from .components.loggers import logger_configurer
 
 
-def run(domain, 
+def run(*,
+        domain, 
         reports_path, 
         reports_list=[],
         summary_filepath="",
